@@ -3,14 +3,14 @@ try:
 except ImportError as e:
     from . import _write_py as _write
 
-from ._write_common import SCHEMA_DEFS
-
+SCHEMA_DEFS = _write.SCHEMA_DEFS
 acquaint_schema = _write.acquaint_schema
 dump = _write.dump
 writer = _write.writer
 Writer = _write.Writer
 schemaless_writer = _write.schemaless_writer
 write_data = _write.write_data
+_validate = _write.validate
 
 WRITERS = _write.WRITERS
 LOGICAL_WRITERS = _write.LOGICAL_WRITERS
